DeviceCapabilities class

Platform capability flags indicating which hardware metrics are supported.

Constructors

DeviceCapabilities({bool cpuInfo = false, bool cpuUsage = false, bool cpuFrequency = false, bool perCoreUsage = false, bool gpuInfo = false, bool memoryInfo = false, bool storageInfo = false, bool batteryInfo = false, bool networkInfo = false, bool sensorInfo = false})
const
DeviceCapabilities.fromMap(Map<String, dynamic> map)
Creates a DeviceCapabilities from a native Map response.
factory

Properties

batteryInfo → bool
final
cpuFrequency → bool
final
cpuInfo → bool
final
cpuUsage → bool
final
gpuInfo → bool
final
hashCode → int
The hash code for this object.
no setterinherited
memoryInfo → bool
final
networkInfo → bool
final
perCoreUsage → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sensorInfo → bool
final
storageInfo → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts this model to a Map representation.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited