SystemInfo class

Aggregated system specifications and metrics snapshot.

Constructors

SystemInfo({CpuInfo? cpu, MemoryInfo? memory, GpuInfo? gpu, List<StorageInfo> storage = const [], BatteryInfo? battery, DeviceInfo? device, OsInfo? os, List<NetworkInfo> network = const [], List<SensorInfo> sensors = const [], DeviceCapabilities? capabilities})
const
SystemInfo.fromMap(Map<String, dynamic> map)
Creates a SystemInfo from a native Map response.
factory

Properties

battery → BatteryInfo?
Battery status and capacity.
final
capabilities → DeviceCapabilities?
Feature capability support flags.
final
cpu → CpuInfo?
Processor hardware details.
final
device → DeviceInfo?
Hardware device metadata.
final
gpu → GpuInfo?
Graphics processing unit details.
final
hashCode → int
The hash code for this object.
no setterinherited
memory → MemoryInfo?
RAM and swap memory status.
final
network → List<NetworkInfo>
Active network interfaces list.
final
os → OsInfo?
Operating system details.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sensors → List<SensorInfo>
Hardware sensors list.
final
storage → List<StorageInfo>
Storage volumes list.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts this model to a Map representation.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited