SystemMetrics class

Periodic dynamic system performance metrics snapshot.

Constructors

SystemMetrics({required DateTime timestamp, double? cpuUsagePercent, List<double> perCoreCpuUsagePercent = const [], double? memoryUsagePercent, int? availableMemoryBytes, double? batteryLevelPercent, bool? isCharging, int? storageFreeBytes, double? networkRxBytesPerSecond, double? networkTxBytesPerSecond})
const
SystemMetrics.fromMap(Map<String, dynamic> map)
Creates a SystemMetrics from a native Map response.
factory

Properties

availableMemoryBytes → int?
Available memory in bytes.
final
batteryLevelPercent → double?
Current battery level percentage (0.0 to 100.0).
final
cpuUsagePercent → double?
Overall CPU utilization percentage (0.0 to 100.0).
final
hashCode → int
The hash code for this object.
no setterinherited
isCharging → bool?
Whether battery is currently charging.
final
memoryUsagePercent → double?
Memory usage percentage (0.0 to 100.0).
final
networkRxBytesPerSecond → double?
Network bytes received per second.
final
networkTxBytesPerSecond → double?
Network bytes transmitted per second.
final
perCoreCpuUsagePercent → List<double>
Per-core CPU utilization percentages.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageFreeBytes → int?
Available free primary storage in bytes.
final
timestamp → DateTime
Timestamp of metric capture.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts this model to a Map representation.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited