CpuCoreInfo class
Detailed metrics for a single CPU core.
Constructors
- CpuCoreInfo({required int id, double? usagePercent, double? currentFrequencyMHz, double? minFrequencyMHz, double? maxFrequencyMHz})
-
const
-
CpuCoreInfo.fromMap(Map<
String, dynamic> map) -
Creates a CpuCoreInfo from a native Map response.
factory
Properties
- currentFrequencyMHz → double?
-
Current clock frequency in MHz.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
Core identifier/index (e.g., 0, 1, 2...).
final
- maxFrequencyMHz → double?
-
Maximum clock frequency supported in MHz.
final
- minFrequencyMHz → double?
-
Minimum clock frequency supported in MHz.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- usagePercent → double?
-
Current usage percentage (0.0 to 100.0).
final
Methods
-
copyWith(
{int? id, double? usagePercent, double? currentFrequencyMHz, double? minFrequencyMHz, double? maxFrequencyMHz}) → CpuCoreInfo -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converts this model to a Map representation.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override